@@ -7,7 +7,7 @@ use 5.008_001;
 use DBI;
 use Time::HiRes qw(gettimeofday tv_interval);
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 my $org_execute               = \&DBI::st::execute;
 my $org_db_do                 = \&DBI::db::do;
@@ -301,7 +301,7 @@ If you want to localize the scope are:
 
 Now you could enable logging between `begin` and `end`.
 
-head2 LOG_LEVEL
+=head2 LOG_LEVEL
 
 If you want to change log_level are:
 
